intelmq.bots.experts.domain_valid package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.domain_valid package

## Submodules

## intelmq.bots.experts.domain_valid.expert module

Domain validator

SPDX-FileCopyrightText: 2021 Marius Karotkis <marius.karotkis@gmail.com> SPDX-License-Identifier: AGPL-3.0-or-later

intelmq.bots.experts.domain_valid.expert.BOT

  alias of `intelmq.bots.experts.domain_valid.expert.DomainValidExpertBot`

class intelmq.bots.experts.domain_valid.expert.DomainValidExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  domain_field: str = 'source.fqdn'
  get_tlds_domain_list()
  init()
  process()
  classmethod run(parsed_args=None)
  tlds_domains_list: str = '/opt/intelmq/var/lib/bots/domain_valid/tlds-alpha-by-domain.txt'
  classmethod update_database(verbose=False)

## Module contents